@@ -1,6 +1,6 @@
 use std::{convert::TryFrom, fmt, thread, time::Duration};
 
-use log::{debug, info, trace};
+use log::info;
 use midly::Timing;
 
 use crate::{Event, Moment};
@@ -27,7 +27,7 @@ pub trait Timer {
 	/// The provided implementation will not sleep if
 	/// `self.sleep_duration(n_ticks).is_zero()`.
 	///
-	/// Using the [log] crate, if the log level is set to `debug`,
+	/// With the provided implementation: If the `verbose-log` feature is enabled and the log level is set to `debug`,
 	/// the sleep duration will be logged before any sleep happens.
 	/// If the log level is set to `trace`, the times when the returned duration
 	/// is 0 (does not cause [thread::sleep]), will also be logged.
@@ -35,10 +35,12 @@ pub trait Timer {
 		let t = self.sleep_duration(n_ticks);
 
 		if !t.is_zero() {
-			debug!(target: "Timer", "sleeping the thread for {:?}", &t);
+			#[cfg(feature = "verbose-log")]
+			log::debug!(target: "Timer", "sleeping the thread for {:?}", &t);
 			thread::sleep(t);
 		} else {
-			trace!(target: "Timer", "timer returned 0 duration, not sleeping")
+			#[cfg(feature = "verbose-log")]
+			log::trace!(target: "Timer", "timer returned 0 duration, not sleeping")
 		}
 	}
 
@@ -47,23 +49,21 @@ pub trait Timer {
 	/// # Notes
 	/// The default implementation modifies `self` if a tempo event is found.
 	fn duration(&mut self, moments: &[Moment]) -> Duration {
-		let mut total = Duration::default();
-		let mut empty_counter = 0_u32;
+		let mut counter = Duration::default();
 		for moment in moments {
+			counter += self.sleep_duration(1);
 			match moment {
-				Moment::Empty => empty_counter += 1,
-				Moment::Events(events) => {
-					total += self.sleep_duration(empty_counter);
-					empty_counter = 0;
+				Moment::Events(events) if !events.is_empty() => {
 					for event in events {
 						if let Event::Tempo(val) = event {
 							self.change_tempo(*val);
 						}
 					}
 				}
-			}
+				_ => (),
+			};
 		}
-		total
+		counter
 	}
 }
 
@@ -91,7 +91,8 @@ impl fmt::Display for TimeFormatError {
 /// Use this when the MIDI file header specifies the time format as being
 /// [Timing::Metrical], this is the case 99% of the time.
 ///
-/// Set the log level to `info` (using the [log] crate) for logging the tempo change events.
+/// Set the log level to `info` (using the [log] crate) for logging the tempo
+/// change events.
 #[derive(Debug, Copy, Clone, PartialEq)]
 pub struct Ticker {
 	ticks_per_beat: u16,
